@@ -1,38 +1,9 @@
-# vers anterior AML2310.py
 import json
 import os
 import sys
 
 from ._request_handler import retry_session, general_call
 
-host = 'https://alchemyml.com'
-url_base = host + '/api'
-
-class authentication():
-    def get_api_token(self, username, password):
-        '''
-        This method returns the necessary token to be used from now on for the 
-        API requests. To be able to make use of the API before all it is 
-        necessary to sign-up.
-
-        Parameters:
-
-        username (str): Username. 
-        password (str): Password. 
-        '''
-        url = url_base + '/token/'
-        data = json.dumps({'username':username, 'password':password})
-        session = retry_session(retries = 10)
-        r = session.post(url, data, verify = False)
-
-        if r.status_code == 200:
-            tokenJSON = json.loads(r.text)
-            return tokenJSON['access']
-        else:
-            msgJSON = json.loads(r.text)
-            msg = msgJSON['message']
-            return msg
-
 class dataset():
 
     class_name = sys._getframe().f_code.co_name
@@ -61,7 +32,7 @@ class dataset():
         input_args = locals()['args']
         input_kwargs = locals()['kwargs']
 
-        return general_call(str_meth_name, input_args, input_kwargs)
+        return general_call(self, str_meth_name, input_args, input_kwargs)
 
     def get(self, *args, **kwargs):
         '''
@@ -84,7 +55,7 @@ class dataset():
         input_args = locals()['args']
         input_kwargs = locals()['kwargs']
 
-        return general_call(str_meth_name, input_args, input_kwargs)
+        return general_call(self, str_meth_name, input_args, input_kwargs)
     
     def update(self, *args, **kwargs):
         '''
@@ -106,7 +77,7 @@ class dataset():
         input_args = locals()['args']
         input_kwargs = locals()['kwargs']
 
-        return general_call(str_meth_name, input_args, input_kwargs)
+        return general_call(self, str_meth_name, input_args, input_kwargs)
 
     def delete(self, *args, **kwargs):
         '''
@@ -130,7 +101,7 @@ class dataset():
         input_args = locals()['args']
         input_kwargs = locals()['kwargs']
 
-        return general_call(str_meth_name, input_args, input_kwargs)
+        return general_call(self, str_meth_name, input_args, input_kwargs)
 
     def statistical_descriptors(self, *args, **kwargs):
         '''
@@ -147,7 +118,7 @@ class dataset():
         input_args = locals()['args']
         input_kwargs = locals()['kwargs']
 
-        return general_call(str_meth_name, input_args, input_kwargs)
+        return general_call(self, str_meth_name, input_args, input_kwargs)
 
 class experiment():
 
@@ -189,7 +160,7 @@ class experiment():
         input_args = locals()['args']
         input_kwargs = locals()['kwargs']
 
-        return general_call(str_meth_name, input_args, input_kwargs)
+        return general_call(self, str_meth_name, input_args, input_kwargs)
 
     def get(self, *args, **kwargs):
         '''
@@ -213,7 +184,7 @@ class experiment():
         input_args = locals()['args']
         input_kwargs = locals()['kwargs']
 
-        return general_call(str_meth_name, input_args, input_kwargs)
+        return general_call(self, str_meth_name, input_args, input_kwargs)
 
     def update(self, *args, **kwargs):
         '''
@@ -236,7 +207,7 @@ class experiment():
         input_args = locals()['args']
         input_kwargs = locals()['kwargs']
 
-        return general_call(str_meth_name, input_args, input_kwargs)
+        return general_call(self, str_meth_name, input_args, input_kwargs)
 
     def delete(self, *args, **kwargs):
         '''
@@ -256,7 +227,7 @@ class experiment():
         input_args = locals()['args']
         input_kwargs = locals()['kwargs']
 
-        return general_call(str_meth_name, input_args, input_kwargs)
+        return general_call(self, str_meth_name, input_args, input_kwargs)
 
     def statistical_descriptors(self, *args, **kwargs):
         '''
@@ -273,7 +244,7 @@ class experiment():
         input_args = locals()['args']
         input_kwargs = locals()['kwargs']
 
-        return general_call(str_meth_name, input_args, input_kwargs)
+        return general_call(self, str_meth_name, input_args, input_kwargs)
 
     def results(self, *args, **kwargs):
         '''
@@ -298,7 +269,7 @@ class experiment():
         input_args = locals()['args']
         input_kwargs = locals()['kwargs']
 
-        return general_call(str_meth_name, input_args, input_kwargs)
+        return general_call(self, str_meth_name, input_args, input_kwargs)
 
     def add_to_project(self, *args, **kwargs):
         '''
@@ -325,7 +296,7 @@ class experiment():
         input_args = locals()['args']
         input_kwargs = locals()['kwargs']
 
-        return general_call(str_meth_name, input_args, input_kwargs)
+        return general_call(self, str_meth_name, input_args, input_kwargs)
 
     def extract_from_project(self, *args, **kwargs):
         '''
@@ -344,7 +315,7 @@ class experiment():
         input_args = locals()['args']
         input_kwargs = locals()['kwargs']
 
-        return general_call(str_meth_name, input_args, input_kwargs)
+        return general_call(self, str_meth_name, input_args, input_kwargs)
 
     def send(self, *args, **kwargs):
         '''
@@ -366,7 +337,7 @@ class experiment():
         input_args = locals()['args']
         input_kwargs = locals()['kwargs']
 
-        return general_call(str_meth_name, input_args, input_kwargs)
+        return general_call(self, str_meth_name, input_args, input_kwargs)
 
 class project():
 
@@ -396,7 +367,7 @@ class project():
         input_args = locals()['args']
         input_kwargs = locals()['kwargs']
 
-        return general_call(str_meth_name, input_args, input_kwargs)    
+        return general_call(self, str_meth_name, input_args, input_kwargs)    
 
     def get(self, *args, **kwargs):
         '''
@@ -419,7 +390,7 @@ class project():
         input_args = locals()['args']
         input_kwargs = locals()['kwargs']
 
-        return general_call(str_meth_name, input_args, input_kwargs) 
+        return general_call(self, str_meth_name, input_args, input_kwargs) 
 
     def update(self, *args, **kwargs):
         '''
@@ -441,7 +412,7 @@ class project():
         input_args = locals()['args']
         input_kwargs = locals()['kwargs']
 
-        return general_call(str_meth_name, input_args, input_kwargs)    
+        return general_call(self, str_meth_name, input_args, input_kwargs)    
 
     def delete(self, *args, **kwargs):
         '''
@@ -461,5 +432,5 @@ class project():
         input_args = locals()['args']
         input_kwargs = locals()['kwargs']
 
-        return general_call(str_meth_name, input_args, input_kwargs)    
+        return general_call(self, str_meth_name, input_args, input_kwargs)    
      
